@@ -3,7 +3,7 @@ class MetalController < ActionController::Metal
   include ActionController::Head
   include Doorkeeper::Rails::Helpers
 
-  before_filter :doorkeeper_authorize!
+  before_action :doorkeeper_authorize!
 
   def index
     self.response_body = { ok: true }.to_json
